@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0400';
 
 use Moo;
 use strictures 2;
@@ -82,7 +82,10 @@ sub BUILD {
     $self->loop->add($midi_rtn);
     $self->_midi_channel->configure(
         on_recv => sub ($channel, $event) {
-            $self->_filter_and_forward($event);
+            my $dt = shift @$event;
+            $event = shift @$event;
+            print "Delta time: $dt, Event: @$event\n" if $self->verbose;
+            $self->_filter_and_forward($dt, $event);
         }
     );
 
@@ -110,14 +113,14 @@ sub _open_port($device, $name) {
 sub _rtmidi_loop ($msg_ch, $midi_ch) {
     my $midi_in = MIDI::RtMidi::FFI::Device->new(type => 'in');
     _open_port($midi_in, ${ $msg_ch->recv });
-    $midi_in->set_callback_decoded(sub { $midi_ch->send($_[2]) });
+    $midi_in->set_callback_decoded(sub { $midi_ch->send([ @_[0, 2] ]) });
     sleep;
 }
 
-sub _filter_and_forward ($self, $event) {
+sub _filter_and_forward ($self, $dt, $event) {
     my $event_filters = $self->filters->{ $event->[0] } // [];
     for my $filter ($event_filters->@*) {
-        return if $filter->($event);
+        return if $filter->($dt, $event);
     }
     $self->send_it($event);
 }
@@ -164,7 +167,7 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0301
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -180,7 +183,7 @@ version 0.0301
     return $note, $note + 7, $note + 12;
   }
   sub filter_tone {
-    my ($event) = @_;
+    my ($delta_time, $event) = @_; # 2 required filter arguments
     my ($ev, $channel, $note, $vel) = $event->@*;
     my @notes = filter_notes($note);
     $rtc->send_it([ $ev, $channel, $_, $vel ]) for @notes;
